==> tv_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/seventhsky/ipb/ActivateTerminalResponse.java <==

package ru.bitel.bgbilling.modules.tv.dyn.seventhsky.ipb;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="terminalID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="freeDays" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "terminalID",
    "freeDays"
})
@XmlRootElement(name = "activateTerminalResponse")
public class ActivateTerminalResponse {

    protected int terminalID;
    protected int freeDays;

    /**
     * Gets the value of the terminalID property.
     * 
     */
    public int getTerminalID() {
        return terminalID;
    }

    /**
     * Sets the value of the terminalID property.
     * 
     */
    public void setTerminalID(int value) {
        this.terminalID = value;
    }

    /**
     * Gets the value of the freeDays property.
     * 
     */
    public int getFreeDays() {
        return freeDays;
    }

    /**
     * Sets the value of the freeDays property.
     * 
     */
    public void setFreeDays(int value) {
        this.freeDays = value;
    }

}

==> tv_9.2501-2511201924.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/seventhsky/ipb/ActivateTerminalResponse.java <==

package ru.bitel.bgbilling.modules.tv.dyn.seventhsky.ipb;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="terminalID" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="freeDays" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "terminalID",
    "freeDays"
})
@XmlRootElement(name = "activateTerminalResponse")
public class ActivateTerminalResponse {

    protected int terminalID;
    protected int freeDays;

    /**
     * Gets the value of the terminalID property.
     * 
     */
    public int getTerminalID() {
        return terminalID;
    }

    /**
     * Sets the value of the terminalID property.
     * 
     */
    public void setTerminalID(int value) {
        this.terminalID = value;
    }

    /**
     * Gets the value of the freeDays property.
     * 
     */
    public int getFreeDays() {
        return freeDays;
    }

    /**
     * Sets the value of the freeDays property.
     * 
     */
    public void setFreeDays(int value) {
        this.freeDays = value;
    }

}
